﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net;
using System.Threading;

namespace com.alu.ot.ics.api.samples
{
    /// <summary>
    /// Entry point of the sample 
    /// </summary>
    public class Program
    {
        static void Main(string[] args)
        {
            Thread.CurrentThread.Name = "Main";
            //Bypass all certificates validation stuff ...
            ServicePointManager.ServerCertificateValidationCallback += (sender, cert, chain, sslPolicyErrors) => true;

            Options options = new Options();
            if (CommandLine.Parser.Default.ParseArguments(args, options))
            {
                Console.WriteLine("**************************************");
                Console.WriteLine("* In this test a caller will initiate a call to a callee ... ");

                //Connect and open session for caller:
                BasicOpenTouchRestClient callerClient = new BasicOpenTouchRestClient();
                callerClient.connect(options.host, options.callerLogin, options.callerPwd);
                HttpStatusCode callerStatus = callerClient.openSession(options.callerLogin + "SampleAPP");
                Console.WriteLine("Caller session open returned: " + callerStatus);

                //Connect and open session for callee:
                BasicOpenTouchRestClient calleeClient = new BasicOpenTouchRestClient();
                calleeClient.connect(options.host, options.calleeLogin, options.calleePwd);
                HttpStatusCode calleeStatus = calleeClient.openSession(options.calleeLogin + "SampleAPP");
                Console.WriteLine("Callee session open returned: " + callerStatus);
                Thread.Sleep(3000);

                // Make call caller => callee
                HttpStatusCode makeStatus = callerClient.makeCall(options.callerDevice, options.calleeNb);
                Console.WriteLine("MakeCall Operation returned: " + makeStatus);
                Console.WriteLine("Waiting 10 secs ...");
                Thread.Sleep(10000);

                // Callee takes the call:
                HttpStatusCode takeStatus = calleeClient.takeCall(options.calleeDevice);
                Console.WriteLine("TakeCall Operation returned: " + takeStatus);
                Console.WriteLine("Caller and callee should be in conversation...");
                Console.WriteLine("Waiting 10 secs ...");
                Thread.Sleep(10000);

                // Caller terminates the call:
                HttpStatusCode dropStatus = callerClient.dropCall();
                Console.WriteLine("DropCall Operation returned: " + takeStatus);

                // End - cleaning:                
                callerClient.closeSession();
                calleeClient.closeSession();
            }
            else
            {
                Console.WriteLine("Can not parse the arguments. Check for mandatory parameters.");
                options.GetUsage();
            }

            Console.Write("Press Enter to exit ...");
            Console.Read();

            Environment.Exit(0);
        }

    }
}
